ContainmentType Type
Describes the relationship between a frustum and a bounded volume.
Record fields
| Record Field |
Description
|
|
|
|
|
|
|
Describes the relationship between a frustum and a bounded volume.
| Record Field |
Description
|
|
|
|
|
|
|