Header menu logo Mibo.Raylib

Frustum Type

Represents a view frustum defined by six planes extracted from a View*Projection matrix.

Each plane is stored as a Vector4 where (x, y, z) is the normal and w is the distance from the origin along the normal direction.

Constructors

Constructor Description

Frustum(viewProjection)

Full Usage: Frustum(viewProjection)

Parameters:
Returns: Frustum
viewProjection : Matrix4x4
Returns: Frustum

Instance members

Instance member Description

this.Contains

Full Usage: this.Contains

Parameters:
Returns: ContainmentType

Tests whether the given BoundingBox is contained within the frustum.

box : BoundingBox
Returns: ContainmentType

this.Contains

Full Usage: this.Contains

Parameters:
Returns: ContainmentType

Tests whether the given BoundingSphere is contained within the frustum.

sphere : BoundingSphere
Returns: ContainmentType

Type something to start searching.