Header menu logo Mibo.Raylib

GameContext Type

Context passed to init, update, and subscribe functions, providing access to game services and runtime information.

This is the primary way to access game services (assets, input, etc.) from within the Elmish architecture. Use GameContext.getService or the typed accessor conveniences to retrieve registered services.

Instance members

Instance member Description

this.WindowHeight

Full Usage: this.WindowHeight

Returns: int

Current window height in pixels.

Returns: int

this.WindowWidth

Full Usage: this.WindowWidth

Returns: int

Current window width in pixels.

Returns: int

Type something to start searching.