Header menu logo Mibo.Raylib

Occluder2D Type

A shadow-casting occluder defined as a line segment.

Record fields

Record Field Description

P1

Full Usage: P1

Field type: Vector2

Start point of the occluder segment in world space.

Field type: Vector2

P2

Full Usage: P2

Field type: Vector2

End point of the occluder segment in world space.

Field type: Vector2

Type something to start searching.