Header menu logo Mibo.Raylib

Renderer3D Module

Convenience constructors for Renderer3D.

Functions and values

Function or value Description

create pipeline view

Full Usage: create pipeline view

Parameters:
Returns: IRenderer<'Model>

Creates a renderer with default configuration (black clear color).

pipeline : IRenderPipeline3D

The 3D rendering pipeline that interprets commands.

view : GameContext -> 'Model -> RenderBuffer3D -> unit

The view function that populates the render buffer each frame.

Returns: IRenderer<'Model>

createWith config pipeline view

Full Usage: createWith config pipeline view

Parameters:
Returns: IRenderer<'Model>

Creates a renderer with custom configuration.

config : Renderer3DConfig

The renderer configuration.

pipeline : IRenderPipeline3D

The 3D rendering pipeline that interprets commands.

view : GameContext -> 'Model -> RenderBuffer3D -> unit

The view function that populates the render buffer each frame.

Returns: IRenderer<'Model>

Type something to start searching.