KeyboardDelta Type
Keyboard state delta containing keys that changed this frame.
Record fields
| Record Field |
Description
|
|
|
|
|
Keyboard state delta containing keys that changed this frame.
| Record Field |
Description
|
|
|
|
|