Header menu logo Mibo.Raylib

Layout Module

Functions and values

Function or value Description

border x y width height content section

Full Usage: border x y width height content section

Parameters:
    x : int
    y : int
    width : int
    height : int
    content : 'T
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
x : int
y : int
width : int
height : int
content : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

center w h f parent

Full Usage: center w h f parent

Parameters:
Returns: GridSection2D<'T>
Modifiers: inline
Type parameters: 'T
w : int
h : int
f : GridSection2D<'T> -> GridSection2D<'T>
parent : GridSection2D<'T>
Returns: GridSection2D<'T>

checker odd even section

Full Usage: checker odd even section

Parameters:
Returns: GridSection2D<'T>
odd : 'T
even : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

checkerBorder x y width height odd even section

Full Usage: checkerBorder x y width height odd even section

Parameters:
    x : int
    y : int
    width : int
    height : int
    odd : 'T
    even : 'T
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
x : int
y : int
width : int
height : int
odd : 'T
even : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

circle cx cy radius filled content section

Full Usage: circle cx cy radius filled content section

Parameters:
    cx : int
    cy : int
    radius : int
    filled : bool
    content : 'T
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
cx : int
cy : int
radius : int
filled : bool
content : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

clear x y width height section

Full Usage: clear x y width height section

Parameters:
    x : int
    y : int
    width : int
    height : int
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
x : int
y : int
width : int
height : int
section : GridSection2D<'T>
Returns: GridSection2D<'T>

corners x y width height content section

Full Usage: corners x y width height content section

Parameters:
    x : int
    y : int
    width : int
    height : int
    content : 'T
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
x : int
y : int
width : int
height : int
content : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

fill x y width height content section

Full Usage: fill x y width height content section

Parameters:
    x : int
    y : int
    width : int
    height : int
    content : 'T
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
x : int
y : int
width : int
height : int
content : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

flowX step stamps parent

Full Usage: flowX step stamps parent

Parameters:
Returns: GridSection2D<'T>
Modifiers: inline
Type parameters: 'T
step : int
stamps : (GridSection2D<'T> -> GridSection2D<'T>) seq
parent : GridSection2D<'T>
Returns: GridSection2D<'T>

flowY step stamps parent

Full Usage: flowY step stamps parent

Parameters:
Returns: GridSection2D<'T>
Modifiers: inline
Type parameters: 'T
step : int
stamps : (GridSection2D<'T> -> GridSection2D<'T>) seq
parent : GridSection2D<'T>
Returns: GridSection2D<'T>

generate x y width height generator section

Full Usage: generate x y width height generator section

Parameters:
    x : int
    y : int
    width : int
    height : int
    generator : int -> int -> 'T
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
Modifiers: inline
Type parameters: 'T
x : int
y : int
width : int
height : int
generator : int -> int -> 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

iter x y width height action section

Full Usage: iter x y width height action section

Parameters:
    x : int
    y : int
    width : int
    height : int
    action : int -> int -> 'T voption -> unit
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
Modifiers: inline
Type parameters: 'T
x : int
y : int
width : int
height : int
action : int -> int -> 'T voption -> unit
section : GridSection2D<'T>
Returns: GridSection2D<'T>

line x1 y1 x2 y2 content section

Full Usage: line x1 y1 x2 y2 content section

Parameters:
    x1 : int
    y1 : int
    x2 : int
    y2 : int
    content : 'T
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
x1 : int
y1 : int
x2 : int
y2 : int
content : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

map x y width height mapping section

Full Usage: map x y width height mapping section

Parameters:
    x : int
    y : int
    width : int
    height : int
    mapping : 'T -> 'T
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
Modifiers: inline
Type parameters: 'T
x : int
y : int
width : int
height : int
mapping : 'T -> 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

padding n f parent

Full Usage: padding n f parent

Parameters:
Returns: GridSection2D<'T>
Modifiers: inline
Type parameters: 'T
n : int
f : GridSection2D<'T> -> GridSection2D<'T>
parent : GridSection2D<'T>
Returns: GridSection2D<'T>

paddingEx left top right bottom f parent

Full Usage: paddingEx left top right bottom f parent

Parameters:
Returns: GridSection2D<'T>
Modifiers: inline
Type parameters: 'T
left : int
top : int
right : int
bottom : int
f : GridSection2D<'T> -> GridSection2D<'T>
parent : GridSection2D<'T>
Returns: GridSection2D<'T>

polygon points filled content section

Full Usage: polygon points filled content section

Parameters:
    points : (int * int)[]
    filled : bool
    content : 'T
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
points : (int * int)[]
filled : bool
content : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

rect x y width height borderContent fillContent section

Full Usage: rect x y width height borderContent fillContent section

Parameters:
    x : int
    y : int
    width : int
    height : int
    borderContent : 'T
    fillContent : 'T
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
x : int
y : int
width : int
height : int
borderContent : 'T
fillContent : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

repeatX x y count content section

Full Usage: repeatX x y count content section

Parameters:
    x : int
    y : int
    count : int
    content : 'T
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
x : int
y : int
count : int
content : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

repeatY x y count content section

Full Usage: repeatY x y count content section

Parameters:
    x : int
    y : int
    count : int
    content : 'T
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
x : int
y : int
count : int
content : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

replace oldContent newContent section

Full Usage: replace oldContent newContent section

Parameters:
Returns: GridSection2D<'T>
oldContent : 'T
newContent : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

replaceScatter oldContent newContent probability seed section

Full Usage: replaceScatter oldContent newContent probability seed section

Parameters:
    oldContent : 'T
    newContent : 'T
    probability : float32
    seed : int
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
oldContent : 'T
newContent : 'T
probability : float32
seed : int
section : GridSection2D<'T>
Returns: GridSection2D<'T>

run f grid

Full Usage: run f grid

Parameters:
Returns: CellGrid2D<'T>
Modifiers: inline
Type parameters: 'T
f : GridSection2D<'T> -> GridSection2D<'T>
grid : CellGrid2D<'T>
Returns: CellGrid2D<'T>

scatter count seed content section

Full Usage: scatter count seed content section

Parameters:
    count : int
    seed : int
    content : 'T
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
count : int
seed : int
content : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

scatterBorder x y width height count seed content section

Full Usage: scatterBorder x y width height count seed content section

Parameters:
    x : int
    y : int
    width : int
    height : int
    count : int
    seed : int
    content : 'T
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
x : int
y : int
width : int
height : int
count : int
seed : int
content : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

scatterLine x1 y1 x2 y2 count seed content section

Full Usage: scatterLine x1 y1 x2 y2 count seed content section

Parameters:
    x1 : int
    y1 : int
    x2 : int
    y2 : int
    count : int
    seed : int
    content : 'T
    section : GridSection2D<'T>

Returns: GridSection2D<'T>
x1 : int
y1 : int
x2 : int
y2 : int
count : int
seed : int
content : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

scatterStamp count seed stamp section'

Full Usage: scatterStamp count seed stamp section'

Parameters:
Returns: GridSection2D<'T>
Modifiers: inline
Type parameters: 'T
count : int
seed : int
stamp : GridSection2D<'T> -> GridSection2D<'T>
section' : GridSection2D<'T>
Returns: GridSection2D<'T>

section x y f parent

Full Usage: section x y f parent

Parameters:
Returns: GridSection2D<'T>
Modifiers: inline
Type parameters: 'T
x : int
y : int
f : GridSection2D<'T> -> GridSection2D<'T>
parent : GridSection2D<'T>
Returns: GridSection2D<'T>

set x y content section

Full Usage: set x y content section

Parameters:
Returns: GridSection2D<'T>
x : int
y : int
content : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

setIfEmpty x y content section

Full Usage: setIfEmpty x y content section

Parameters:
Returns: GridSection2D<'T>
x : int
y : int
content : 'T
section : GridSection2D<'T>
Returns: GridSection2D<'T>

Type something to start searching.