Shaders Module
Built-in GLSL shader generators for the Forward PBR pipeline.
Fragment shaders use uniform arrays for point lights. The array size is determined at pipeline creation time (default 8) because GLSL requires compile-time constants for array declarations.
Functions and values
| Function or value |
Description
|
Full Usage:
depthShadowFragment
Returns: string
|
|
Full Usage:
depthShadowVertex
Returns: string
|
|
Full Usage:
forwardFragmentFmt maxPointLights maxSpotLights maxShadowCasters
Parameters:
int
maxSpotLights : int
maxShadowCasters : int
Returns: string
|
|
Full Usage:
forwardVertex
Returns: string
|
|
Full Usage:
forwardVertexInstanced
Returns: string
|
Instanced variant of the forward vertex shader.
Uses
|
|
Loads the depth-only shadow pass vertex + fragment shader (C example compatible).
|
Full Usage:
loadForwardInstancedShader maxPointLights maxSpotLights maxShadowCasters
Parameters:
int
maxSpotLights : int
maxShadowCasters : int
Returns: Shader
|
Loads the instanced forward PBR vertex + fragment shader.
Uses
|
Full Usage:
loadForwardShader maxPointLights maxSpotLights maxShadowCasters
Parameters:
int
maxSpotLights : int
maxShadowCasters : int
Returns: Shader
|
Loads the built-in forward PBR vertex + fragment shader. The fragment shader is generated with the specified light and shadow array sizes.
|
|
|
Full Usage:
postProcessFragment
Returns: string
|
|
Full Usage:
postProcessVertex
Returns: string
|
|
Mibo.Raylib