Renderer3D Module
Convenience constructors for Renderer3D.
Functions and values
| Function or value |
Description
|
Full Usage:
create pipeline view
Parameters:
IRenderPipeline3D
-
The 3D rendering pipeline that interprets commands.
view : GameContext -> 'Model -> RenderBuffer3D -> unit
-
The view function that populates the render buffer each frame.
Returns: IRenderer<'Model>
|
Creates a renderer with default configuration (black clear color).
|
Full Usage:
createWith config pipeline view
Parameters:
Renderer3DConfig
-
The renderer configuration.
pipeline : IRenderPipeline3D
-
The 3D rendering pipeline that interprets commands.
view : GameContext -> 'Model -> RenderBuffer3D -> unit
-
The view function that populates the render buffer each frame.
Returns: IRenderer<'Model>
|
Creates a renderer with custom configuration.
|
Mibo.Raylib