Layout3D Module
Functions and values
| Function or value |
Description
|
Full Usage:
center w h d f parent
Parameters:
int
h : int
d : int
f : GridSection3D<'T> -> GridSection3D<'T>
parent : GridSection3D<'T>
Returns: GridSection3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
checker3D odd even section
Parameters:
'T
even : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
checkerShell x y z w h d odd even section'
Parameters:
int
y : int
z : int
w : int
h : int
d : int
odd : 'T
even : 'T
section' : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
checkerXY z odd even section
Parameters:
int
odd : 'T
even : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
checkerXZ y odd even section
Parameters:
int
odd : 'T
even : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
checkerYZ x odd even section
Parameters:
int
odd : 'T
even : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
clear x y z w h d section
Parameters:
int
y : int
z : int
w : int
h : int
d : int
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
column x y z height content section
Parameters:
int
y : int
z : int
height : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
cylinder cx cz y radius height filled content section
Parameters:
int
cz : int
y : int
radius : int
height : int
filled : bool
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
edges x y z w h d content section
Parameters:
int
y : int
z : int
w : int
h : int
d : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
fill x y z w h d content section
Parameters:
int
y : int
z : int
w : int
h : int
d : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
floorXZ x y z w d content section
Parameters:
int
y : int
z : int
w : int
d : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
flowX step stamps parent
Parameters:
int
stamps : (GridSection3D<'T> -> GridSection3D<'T>) seq
parent : GridSection3D<'T>
Returns: GridSection3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
flowY step stamps parent
Parameters:
int
stamps : (GridSection3D<'T> -> GridSection3D<'T>) seq
parent : GridSection3D<'T>
Returns: GridSection3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
flowZ step stamps parent
Parameters:
int
stamps : (GridSection3D<'T> -> GridSection3D<'T>) seq
parent : GridSection3D<'T>
Returns: GridSection3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
generate x y z w h d generator section
Parameters:
int
y : int
z : int
w : int
h : int
d : int
generator : int -> int -> int -> 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
generateXY z generator section
Parameters:
int
generator : int -> int -> 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
generateXZ y generator section
Parameters:
int
generator : int -> int -> 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
generateYZ x generator section
Parameters:
int
generator : int -> int -> 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
iter x y z w h d action section
Parameters:
int
y : int
z : int
w : int
h : int
d : int
action : int -> int -> int -> 'T voption -> unit
section : GridSection3D<'T>
Returns: GridSection3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
line x1 y1 z1 x2 y2 z2 content section
Parameters:
int
y1 : int
z1 : int
x2 : int
y2 : int
z2 : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
map x y z w h d mapping section
Parameters:
int
y : int
z : int
w : int
h : int
d : int
mapping : 'T -> 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
padding n f parent
Parameters:
int
f : GridSection3D<'T> -> GridSection3D<'T>
parent : GridSection3D<'T>
Returns: GridSection3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
paddingEx left bottom back right top front f parent
Parameters:
int
bottom : int
back : int
right : int
top : int
front : int
f : GridSection3D<'T> -> GridSection3D<'T>
parent : GridSection3D<'T>
Returns: GridSection3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
repeatX x y z count content section
Parameters:
int
y : int
z : int
count : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
repeatY x y z count content section
Parameters:
int
y : int
z : int
count : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
repeatZ x y z count content section
Parameters:
int
y : int
z : int
count : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
replace oldContent newContent section
Parameters:
'T
newContent : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
replaceScatter oldContent newContent probability seed section
Parameters:
'T
newContent : 'T
probability : float32
seed : int
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
run f grid
Parameters:
GridSection3D<'T> -> GridSection3D<'T>
grid : CellGrid3D<'T>
Returns: CellGrid3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
scatter3D count seed content section
Parameters:
int
seed : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
scatterEdges x y z w h d count seed content section
Parameters:
int
y : int
z : int
w : int
h : int
d : int
count : int
seed : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
scatterLine x1 y1 z1 x2 y2 z2 count seed content section
Parameters:
int
y1 : int
z1 : int
x2 : int
y2 : int
z2 : int
count : int
seed : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
scatterShell x y z w h d count seed content section
Parameters:
int
y : int
z : int
w : int
h : int
d : int
count : int
seed : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
scatterStamp count seed stamp section'
Parameters:
int
seed : int
stamp : GridSection3D<'T> -> GridSection3D<'T>
section' : GridSection3D<'T>
Returns: GridSection3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
scatterXY z count seed content section
Parameters:
int
count : int
seed : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
scatterXZ y count seed content section
Parameters:
int
count : int
seed : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
scatterYZ x count seed content section
Parameters:
int
count : int
seed : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
section x y z f parent
Parameters:
int
y : int
z : int
f : GridSection3D<'T> -> GridSection3D<'T>
parent : GridSection3D<'T>
Returns: GridSection3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
set x y z content section
Parameters:
int
y : int
z : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
Modifiers: inline Type parameters: 'T |
|
Full Usage:
setIfEmpty x y z content section
Parameters:
int
y : int
z : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
shell x y z w h d content section
Parameters:
int
y : int
z : int
w : int
h : int
d : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
sphere cx cy cz radius filled content section
Parameters:
int
cy : int
cz : int
radius : int
filled : bool
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
wallXY x y z w h content section
Parameters:
int
y : int
z : int
w : int
h : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Full Usage:
wallYZ x y z h d content section
Parameters:
int
y : int
z : int
h : int
d : int
content : 'T
section : GridSection3D<'T>
Returns: GridSection3D<'T>
|
|
Mibo.Raylib